@@ -11,9 +11,8 @@ class ClusterTask(Task):
 
     @property
     def meta_docstring(self):
-        return self.meta_inspect(
-            name='docstring', lookup=True,
-            default='Invoke "{tasks}" tasks.'.format(tasks=self.__tasks))
+        default = 'Invoke "{tasks}" tasks.'.format(tasks=self.__tasks)
+        return self.meta_inspect('docstring', default=default)
 
     def meta_invoke(self, *args, **kwargs):
         results = []
