@@ -14,7 +14,7 @@ class ClusterTaskTest(unittest.TestCase):
         self.nested_task1 = Mock()
         self.nested_task2 = Mock()
         self.task = component.ClusterTask(
-            [self.nested_task1, self.nested_task2], meta_module=None)
+            [self.nested_task1, self.nested_task2], meta_build=True)
 
     # Tests
 
